using Marco.Pms.Model.Employees;
using Marco.Pms.Model.ViewModels.PaymentGetway;

namespace Marco.Pms.Services.Service.ServiceInterfaces
{
    public interface IRazorpayService
    {
        CreateOrderVM CreateOrder(double amount, Employee loggedInEmployee, Guid tenantId);
        string GetExpectedSignature(string payload);
        Task<PaymentDetailsVM> GetPaymentDetails(string paymentId);
        Task<PaymentDetailsVM> GetPaymentDetailsFromDataBase(Guid id);
        Task<List<PaymentDetailsVM>> GetPaymentDetailsListFromDataBase(List<Guid> paymentDetailsIds);
        RazorpayOrderDetails? GetOrderDetails(string orderId);
    }
}
